========================
Karbor CLI Documentation
========================

In this section you will find information on Karbor's command line
interface.

.. toctree::
   :maxdepth: 1

   karbor-status
